@@ -73,8 +73,8 @@ void	config(int argc, char **argv)
                         }
 			else if (!memcmp (buff, "CMD_MODE", 8))
 			{
-				/* 1 stdin */
-				/* 0 fifo  */
+				/* 0 stdin */
+				/* 1 fifo  */
 				cmdmode = atoi (pnt);
 			}
 			else if (!memcmp (buff, "PORT", 4))
@@ -83,11 +83,11 @@ void	config(int argc, char **argv)
 			}
                         else if (!memcmp (buff, "TRUST_PORT", 10))
                         {
-                                trust_port = atoi(pnt);
+                                trust_port = htons(atoi(pnt));
                         }
 			else if (!memcmp (buff, "TRUST_DB_PORT", 13))
 			{
-				trust_db_port = atoi(pnt);
+				trust_db_port = htons(atoi(pnt));
 			}
 		}
 	}
