@@ -3,6 +3,9 @@
 	Auther	Satoshi Yasuda	7M3TJZ/AD6GZ
 	Mod.
 	2014.01.21 V00.00
+	2014.01.22 V00.01 Bug fixed for from_rig.c
+	2014.01.22 V00.02 Bug fixed for beep.c
+	2014.01.23 V00.03 drop "htons"
 
 */
 
@@ -93,7 +96,7 @@ void	send_dsvt(void)
 			RelayPacket.ip = dstIP;
 			RelayPacket.port = dstPort;
         		sndAddr.sin_family = AF_INET;
-        		sndAddr.sin_port = htons(trust_db_port);
+        		sndAddr.sin_port = trust_db_port;
         		sndAddr.sin_addr = dbIP;
         		sendto (udpSocket, (char *)&RelayPacket, sizeof(RelayPacket), 0,
                 		(struct sockaddr *)&sndAddr, sizeof(sndAddr));
@@ -101,7 +104,7 @@ void	send_dsvt(void)
 		else
 		{
                 	sndAddr.sin_addr = dstIP;
-                	sndAddr.sin_port = htons(dstPort);
+                	sndAddr.sin_port = dstPort;
                 	sndAddr.sin_family = AF_INET;
                 	sendto (udpSocket, &send_pkt, 56, 0,
                         	(struct sockaddr *)&sndAddr, sizeof(sndAddr));
@@ -125,7 +128,7 @@ void	send_dsvt(void)
                         	RelayPacket.ip = dstIP;
                         	RelayPacket.port = dstPort;
                         	sndAddr.sin_family = AF_INET;
-                        	sndAddr.sin_port = htons(trust_db_port);
+                        	sndAddr.sin_port = trust_db_port;
                         	sndAddr.sin_addr = dbIP;
                         	sendto (udpSocket, (char *)&RelayPacket, 33, 0,
                                 	(struct sockaddr *)&sndAddr, sizeof(sndAddr));
