@@ -11,6 +11,7 @@
 #include	<sys/msg.h>
 #include	<mqueue.h>
 #include	"dsgwd_pi.h"
+#include	"node_adapter.h"
 #include	"node.h"
 
 char	headerRead;
@@ -32,7 +33,7 @@ extern	char	LastFrame1[6];
 extern	char	respFlags;
 char	SlowData[6];
 char	voice[12];
-char	header[41];
+
 char 	LastFrameCheckRx[6];
 unsigned char	Packet_Seq;
 unsigned char	Packet_Seq_Save;
@@ -59,13 +60,13 @@ void	from_rig(void)
 	/* rf header read */
 	if (!headerRead)
 	{
-		ret = usb_control_msg (udev, 0xC0, GET_HEADER, 0, 0, header, 32, 100);
+		ret = usb_control_msg (udev, 0xC0, GET_HEADER, 0, 0, rf_header.header1, 32, 100);
         	if (ret != 32)
 		{
 			return;  /*RF header read? */
 		}
 
-        	usb_control_msg (udev, 0xC0, GET_HEADER, 0, 0, &header[32], 9, 100);
+        	usb_control_msg (udev, 0xC0, GET_HEADER, 0, 0, &rf_header.header2, 9, 100);
   		usb_control_msg (udev, 0xC0, GET_AD_STATUS, 0, 0, &status, 1, 100);
 
 		headerRead = TRUE;
@@ -98,8 +99,8 @@ void	from_rig(void)
 					headerRead = FALSE;
 					SendHeader = FALSE;
 					COS_On = FALSE;
-					sprintf (msg,"CALLED FROM %8.8s",&header[27]);
-					if (SendToInet) BeepSend(&header[27], respFlags);
+					sprintf (msg,"CALLED FROM %8.8s",&rf_header.MyCall);
+					if (SendToInet) BeepSend(rf_header.MyCall, respFlags);
 					return;
 				}
 
@@ -137,8 +138,8 @@ void	from_rig(void)
 				}
 
 			}
-
-		} else if (length == 0)
+		}
+		else if (length == 0)
                 {
                         usb_control_msg (udev, 0xC0, GET_AD_STATUS, 0, 0, &status, 1, 100);
                         if (!(status & COS_OnOff))
@@ -211,7 +212,7 @@ void	send_header_queue(void) 	/* read from rig (DV packet) */
 		dv_frame.B_header.PacketID[1] = Packet_ID & 0xff;
 		Packet_Seq = 0;
 
-		memcpy ((char *)&dv_frame.header, (char *)&header, 41);
+		memcpy ((char *)&dv_frame.header, (char *)&rf_header, 41);
 		memcpy ((char *)&dv_frame.header.Rpt1Call, client_call, 8);
 		ret = mq_send (rf_qid, (char *)&dv_frame, sizeof(dv_frame), 1);
 }
